#include "InstallerTypes.r"

include "GetRsrcVersion";

//  This script is set up to use a custom version proc to determine whether
//  or not to replace/update an existing resource.
//  This is the recommended way of determining whether or not to update an
//  existing resource which has a version number somewhere in the resource header.

//  If the correct flags are set, Installer will call the custom proc, which should
//  use the call back routine ReadTargetData to obtain the resource version.

//  The following flags must be set:
//		copy, leaveAloneIfNewer, & update existing.
//  also the 'inra' must have the source version hard-coded.

//	In this example, the resouce will be copied the first time only.  The update will NOT happen,
//	since the custom proc will return the first long of the resource, which is 0x21110000, and
//	the version in the 'inra' below is 0x2110ffff.

resource 'inpk' (100) {
	format0 {
		showsOnCustom,
		removable,
		dontForceRestart,
		0,
		0,
		"Copy File Read Me from Tidbits Disk....",
		{	'inra', 1000	},
		}
	};

resource 'inra' (1000) {
	format1 {
		deleteWhenRemoving,
		deleteWhenInstalling,
		copy,							//  Copy on Install
		leaveAloneIfNewer,				//  Do not update a newer file
		noTgtRequired,
		updateExisting,					//  Update an existing file
		copyIfNewOrUpdate,
		ignoreProtection,
		srcNeedExist,
		byID,
		nameNeedNotMatch,
		0,
		10000,
		'PICT',
		1000,
		0x0,
		"Fubar Pict",
		{	20000, 'PICT', 1000, 0, "WhatEver"	},
		0x2110ffff,						//  The dummy source version number (first long from resource)
		128,							//  MUST be the 'invc' id of the custom version proc
		0,
		"Read Me - PICT"
		}
	};

resource 'invc' (128) {
	format0 {
		'infn',							//  The resource type of the actual custom proc
		128,							//  The resource id of the actual custom proc
		1024,							//  The minimum amount of memory needed by the proc
		"Returns the first long from the target resource.",		//  Will return 0x21110000
		}
	};

resource 'infs' (10000) {
	'rsrc',
	'RSED',
	0x0,
	noSearchForFile,
	TypeCrMustMatch,
	":Read Me - PICT"
	};

resource 'infs' (20000) {
	'ttro',
	'ttxt',
	0x1,							//  Thu, Apr 25, 1991     12:00:00 PM
	noSearchForFile,
	TypeCrMustMatch,
	"Tidbits:Apple Utilities:Read Me"	//  System 7.1 Tidbits FDHD diskette
	};
